part of 'exercise_execute_plan_add_bloc.dart';

@immutable
abstract class ExerciseExecutePlanAddState extends Equatable {
  const ExerciseExecutePlanAddState();

  @override
  List<Object> get props => [];
}

class ExerciseExecutePlanAddInitial extends ExerciseExecutePlanAddState {
  const ExerciseExecutePlanAddInitial();
}

class ExerciseExecutePlanAddLoading extends ExerciseExecutePlanAddState {
  const ExerciseExecutePlanAddLoading();
}

// updated screen
class ExerciseExecutePlanAddReady extends ExerciseExecutePlanAddState {
  const ExerciseExecutePlanAddReady();
}

// error splash screen
class ExerciseExecutePlanAddError extends ExerciseExecutePlanAddState {
  final String message;
  const ExerciseExecutePlanAddError({required this.message});

  @override
  List<Object> get props => [message];
}
